pub struct HealthReporter { /* private fields */ }Expand description
A handle providing methods to update the health status of gRPC services. A
HealthReporter is connected to a HealthServer which serves the statuses
over the grpc.health.v1.Health service.
Implementations
Sourceimpl HealthReporter
impl HealthReporter
Sourcepub fn new() -> HealthReporter
pub fn new() -> HealthReporter
Create a new HealthReporter with an initial service (named “”), corresponding to overall server health
Sourcepub async fn set_serving<S>(&self)where
S: NamedService,
pub async fn set_serving<S>(&self)where
S: NamedService,
Sets the status of the service implemented by S to Serving. This notifies any watchers
if there is a change in status.
Sourcepub async fn set_not_serving<S>(&self)where
S: NamedService,
pub async fn set_not_serving<S>(&self)where
S: NamedService,
Sets the status of the service implemented by S to NotServing. This notifies any watchers
if there is a change in status.
Sourcepub async fn set_service_status<S>(
&self,
service_name: S,
status: ServingStatus,
)
pub async fn set_service_status<S>( &self, service_name: S, status: ServingStatus, )
Sets the status of the service with service_name to status. This notifies any watchers
if there is a change in status.
Sourcepub async fn clear_service_status(&mut self, service_name: &str)
pub async fn clear_service_status(&mut self, service_name: &str)
Clear the status of the given service.