TLS configuration builders for remote TCP gateways.
Structs
- TlsConfig
- PEM files used by a gateway TLS server.
Functions
- client_
tls - Load a server CA and optional client identity for a remote gateway connection.
- server_
tls - Load a server identity and, when configured, require certificates signed by the client CA.